==> gorilla-notes-0.4.0-20200913.104504-3.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$ReactPlayer.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$ReactPlayer=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _interopRequireWildcard(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};
var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";
_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,
sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}
function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _toConsumableArray(arr){var JSCompiler_temp=Array.isArray(arr)?_arrayLikeToArray(arr):void 0;JSCompiler_temp||(JSCompiler_temp="undefined"!==typeof Symbol&&Symbol.iterator in Object(arr)?Array.from(arr):void 0);if(!JSCompiler_temp)a:{if(arr){if("string"===
typeof arr){JSCompiler_temp=_arrayLikeToArray(arr,void 0);break a}JSCompiler_temp=Object.prototype.toString.call(arr).slice(8,-1);"Object"===JSCompiler_temp&&arr.constructor&&(JSCompiler_temp=arr.constructor.name);if("Map"===JSCompiler_temp||"Set"===JSCompiler_temp){JSCompiler_temp=Array.from(JSCompiler_temp);break a}if("Arguments"===JSCompiler_temp||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp)){JSCompiler_temp=_arrayLikeToArray(arr,void 0);break a}}JSCompiler_temp=void 0}if(!(arr=
JSCompiler_temp))throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");return arr}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;
"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});Object.defineProperty(exports,"FilePlayer",{enumerable:!0,
get:function(){return _FilePlayer["default"]}});Object.defineProperty(exports,"YouTube",{enumerable:!0,get:function(){return _YouTube["default"]}});Object.defineProperty(exports,"SoundCloud",{enumerable:!0,get:function(){return _SoundCloud["default"]}});Object.defineProperty(exports,"Vimeo",{enumerable:!0,get:function(){return _Vimeo["default"]}});Object.defineProperty(exports,"Facebook",{enumerable:!0,get:function(){return _Facebook["default"]}});Object.defineProperty(exports,"Streamable",{enumerable:!0,
get:function(){return _Streamable["default"]}});Object.defineProperty(exports,"Wistia",{enumerable:!0,get:function(){return _Wistia["default"]}});Object.defineProperty(exports,"Twitch",{enumerable:!0,get:function(){return _Twitch["default"]}});Object.defineProperty(exports,"DailyMotion",{enumerable:!0,get:function(){return _DailyMotion["default"]}});Object.defineProperty(exports,"Mixcloud",{enumerable:!0,get:function(){return _Mixcloud["default"]}});exports["default"]=void 0;var _react=_interopRequireWildcard(require("module$node_modules$react$index")),
_props=require("module$node_modules$react_player$lib$props"),_utils=require("module$node_modules$react_player$lib$utils"),_players=_interopRequireDefault(require("module$node_modules$react_player$lib$players$index")),_Player4=_interopRequireDefault(require("module$node_modules$react_player$lib$Player")),_Preview=_interopRequireDefault(require("module$node_modules$react_player$lib$Preview")),_FilePlayer=_interopRequireWildcard(require("module$node_modules$react_player$lib$players$FilePlayer")),_preload=
_interopRequireDefault(require("module$node_modules$react_player$lib$preload")),_YouTube=_interopRequireDefault(require("module$node_modules$react_player$lib$players$YouTube")),_SoundCloud=_interopRequireDefault(require("module$node_modules$react_player$lib$players$SoundCloud")),_Vimeo=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Vimeo")),_Facebook=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Facebook")),_Streamable=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Streamable")),
_Wistia=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Wistia")),_Twitch=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Twitch")),_DailyMotion=_interopRequireDefault(require("module$node_modules$react_player$lib$players$DailyMotion")),_Mixcloud=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Mixcloud")),SUPPORTED_PROPS=Object.keys(_props.propTypes),customPlayers=[];global=function(_Component){function ReactPlayer(){if(!(this instanceof
ReactPlayer))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"config",(0,_utils.getConfig)(_this.props,_props.defaultProps,!0));_defineProperty(_assertThisInitialized(_this),"state",{showPreview:!!_this.props.light});_defineProperty(_assertThisInitialized(_this),"handleClickPreview",function(){_this.setState({showPreview:!1})});
_defineProperty(_assertThisInitialized(_this),"showPreview",function(){_this.setState({showPreview:!0})});_defineProperty(_assertThisInitialized(_this),"getDuration",function(){return _this.player?_this.player.getDuration():null});_defineProperty(_assertThisInitialized(_this),"getCurrentTime",function(){return _this.player?_this.player.getCurrentTime():null});_defineProperty(_assertThisInitialized(_this),"getSecondsLoaded",function(){return _this.player?_this.player.getSecondsLoaded():null});_defineProperty(_assertThisInitialized(_this),
"getInternalPlayer",function(){return _this.player?_this.player.getInternalPlayer(0<arguments.length&&void 0!==arguments[0]?arguments[0]:"player"):null});_defineProperty(_assertThisInitialized(_this),"seekTo",function(fraction,type){if(!_this.player)return null;_this.player.seekTo(fraction,type)});_defineProperty(_assertThisInitialized(_this),"handleReady",function(){_this.props.onReady(_assertThisInitialized(_this))});_defineProperty(_assertThisInitialized(_this),"wrapperRef",function(wrapper){_this.wrapper=
wrapper});_defineProperty(_assertThisInitialized(_this),"activePlayerRef",function(player){_this.player=player});return _this}_inherits(ReactPlayer,_Component);var _super=_createSuper(ReactPlayer);_createClass(ReactPlayer,[{key:"componentDidMount",value:function(){this.props.progressFrequency&&console.warn("ReactPlayer: %cprogressFrequency%c is deprecated, please use %cprogressInterval%c instead","font-weight: bold","","font-weight: bold","")}},{key:"shouldComponentUpdate",value:function(nextProps,
nextState){return!(0,_utils.isEqual)(this.props,nextProps)||!(0,_utils.isEqual)(this.state,nextState)}},{key:"componentDidUpdate",value:function(prevProps){var light=this.props.light;this.config=(0,_utils.getConfig)(this.props,_props.defaultProps);!prevProps.light&&light&&this.setState({showPreview:!0});prevProps.light&&!light&&this.setState({showPreview:!1})}},{key:"getActivePlayer",value:function(url){for(var _i=0,_arr=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i<
_arr.length;_i++){var _Player=_arr[_i];if(_Player.canPlay(url))return _Player}return _FilePlayer.FilePlayer}},{key:"renderActivePlayer",value:function(url,activePlayer){return url?_react["default"].createElement(_Player4["default"],_extends({},this.props,{key:activePlayer.displayName,ref:this.activePlayerRef,config:this.config,activePlayer,onReady:this.handleReady})):null}},{key:"sortPlayers",value:function(a,b){return a&&b?a.key<b.key?-1:1:0}},{key:"render",value:function(){var _this$props=this.props,
url=_this$props.url,controls=_this$props.controls,style=_this$props.style,width=_this$props.width,height=_this$props.height,light=_this$props.light,playIcon=_this$props.playIcon;_this$props=_this$props.wrapper;var showPreview=this.state.showPreview&&url,otherProps=(0,_utils.omit)(this.props,SUPPORTED_PROPS,_props.DEPRECATED_CONFIG_PROPS),activePlayer=this.getActivePlayer(url);activePlayer=this.renderActivePlayer(url,activePlayer);controls=(0,_preload["default"])(url,controls,this.config);controls=
[activePlayer].concat(_toConsumableArray(controls)).sort(this.sortPlayers);url=_react["default"].createElement(_Preview["default"],{url,light,playIcon,onClick:this.handleClickPreview});return _react["default"].createElement(_this$props,_extends({ref:this.wrapperRef,style:_objectSpread({},style,{width,height})},otherProps),showPreview?url:controls)}}]);return ReactPlayer}(_react.Component);exports["default"]=global;_defineProperty(global,"addCustomPlayer",function(player){customPlayers.push(player)});
_defineProperty(global,"removeCustomPlayers",function(){customPlayers=[]});_defineProperty(global,"displayName","ReactPlayer");_defineProperty(global,"propTypes",_props.propTypes);_defineProperty(global,"defaultProps",_props.defaultProps);_defineProperty(global,"canPlay",function(url){for(var _i2=0,_arr2=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i2<_arr2.length;_i2++)if(_arr2[_i2].canPlay(url))return!0;return!1});_defineProperty(global,"canEnablePIP",function(url){for(var _i3=
0,_arr3=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i3<_arr3.length;_i3++){var _Player3=_arr3[_i3];if(_Player3.canEnablePIP&&_Player3.canEnablePIP(url))return!0}return!1})}
//# sourceMappingURL=module$node_modules$react_player$lib$ReactPlayer.js.map

==> gorilla-notes-0.5.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$ReactPlayer.js <==
shadow$provide.module$node_modules$react_player$lib$ReactPlayer=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _interopRequireWildcard(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};
var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";
_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,
sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}
function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _toConsumableArray(arr){var JSCompiler_temp=Array.isArray(arr)?_arrayLikeToArray(arr):void 0;JSCompiler_temp||(JSCompiler_temp="undefined"!==typeof Symbol&&Symbol.iterator in Object(arr)?Array.from(arr):void 0);if(!JSCompiler_temp)a:{if(arr){if("string"===
typeof arr){JSCompiler_temp=_arrayLikeToArray(arr,void 0);break a}JSCompiler_temp=Object.prototype.toString.call(arr).slice(8,-1);"Object"===JSCompiler_temp&&arr.constructor&&(JSCompiler_temp=arr.constructor.name);if("Map"===JSCompiler_temp||"Set"===JSCompiler_temp){JSCompiler_temp=Array.from(JSCompiler_temp);break a}if("Arguments"===JSCompiler_temp||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp)){JSCompiler_temp=_arrayLikeToArray(arr,void 0);break a}}JSCompiler_temp=void 0}if(!(arr=
JSCompiler_temp))throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");return arr}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;
"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});Object.defineProperty(exports,"FilePlayer",
{enumerable:!0,get:function(){return _FilePlayer["default"]}});Object.defineProperty(exports,"YouTube",{enumerable:!0,get:function(){return _YouTube["default"]}});Object.defineProperty(exports,"SoundCloud",{enumerable:!0,get:function(){return _SoundCloud["default"]}});Object.defineProperty(exports,"Vimeo",{enumerable:!0,get:function(){return _Vimeo["default"]}});Object.defineProperty(exports,"Facebook",{enumerable:!0,get:function(){return _Facebook["default"]}});Object.defineProperty(exports,"Streamable",
{enumerable:!0,get:function(){return _Streamable["default"]}});Object.defineProperty(exports,"Wistia",{enumerable:!0,get:function(){return _Wistia["default"]}});Object.defineProperty(exports,"Twitch",{enumerable:!0,get:function(){return _Twitch["default"]}});Object.defineProperty(exports,"DailyMotion",{enumerable:!0,get:function(){return _DailyMotion["default"]}});Object.defineProperty(exports,"Mixcloud",{enumerable:!0,get:function(){return _Mixcloud["default"]}});exports["default"]=void 0;var _react=
_interopRequireWildcard(require("module$node_modules$react$index")),_props=require("module$node_modules$react_player$lib$props"),_utils=require("module$node_modules$react_player$lib$utils"),_players=_interopRequireDefault(require("module$node_modules$react_player$lib$players$index")),_Player4=_interopRequireDefault(require("module$node_modules$react_player$lib$Player")),_Preview=_interopRequireDefault(require("module$node_modules$react_player$lib$Preview")),_FilePlayer=_interopRequireWildcard(require("module$node_modules$react_player$lib$players$FilePlayer")),
_preload=_interopRequireDefault(require("module$node_modules$react_player$lib$preload")),_YouTube=_interopRequireDefault(require("module$node_modules$react_player$lib$players$YouTube")),_SoundCloud=_interopRequireDefault(require("module$node_modules$react_player$lib$players$SoundCloud")),_Vimeo=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Vimeo")),_Facebook=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Facebook")),_Streamable=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Streamable")),
_Wistia=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Wistia")),_Twitch=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Twitch")),_DailyMotion=_interopRequireDefault(require("module$node_modules$react_player$lib$players$DailyMotion")),_Mixcloud=_interopRequireDefault(require("module$node_modules$react_player$lib$players$Mixcloud")),SUPPORTED_PROPS=Object.keys(_props.propTypes),customPlayers=[];global=function(_Component){function ReactPlayer(){if(!(this instanceof
ReactPlayer))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"config",(0,_utils.getConfig)(_this.props,_props.defaultProps,!0));_defineProperty(_assertThisInitialized(_this),"state",{showPreview:!!_this.props.light});_defineProperty(_assertThisInitialized(_this),"handleClickPreview",function(){_this.setState({showPreview:!1})});
_defineProperty(_assertThisInitialized(_this),"showPreview",function(){_this.setState({showPreview:!0})});_defineProperty(_assertThisInitialized(_this),"getDuration",function(){return _this.player?_this.player.getDuration():null});_defineProperty(_assertThisInitialized(_this),"getCurrentTime",function(){return _this.player?_this.player.getCurrentTime():null});_defineProperty(_assertThisInitialized(_this),"getSecondsLoaded",function(){return _this.player?_this.player.getSecondsLoaded():null});_defineProperty(_assertThisInitialized(_this),
"getInternalPlayer",function(){return _this.player?_this.player.getInternalPlayer(0<arguments.length&&void 0!==arguments[0]?arguments[0]:"player"):null});_defineProperty(_assertThisInitialized(_this),"seekTo",function(fraction,type){if(!_this.player)return null;_this.player.seekTo(fraction,type)});_defineProperty(_assertThisInitialized(_this),"handleReady",function(){_this.props.onReady(_assertThisInitialized(_this))});_defineProperty(_assertThisInitialized(_this),"wrapperRef",function(wrapper){_this.wrapper=
wrapper});_defineProperty(_assertThisInitialized(_this),"activePlayerRef",function(player){_this.player=player});return _this}_inherits(ReactPlayer,_Component);var _super=_createSuper(ReactPlayer);_createClass(ReactPlayer,[{key:"componentDidMount",value:function(){this.props.progressFrequency&&console.warn("ReactPlayer: %cprogressFrequency%c is deprecated, please use %cprogressInterval%c instead","font-weight: bold","","font-weight: bold","")}},{key:"shouldComponentUpdate",value:function(nextProps,
nextState){return!(0,_utils.isEqual)(this.props,nextProps)||!(0,_utils.isEqual)(this.state,nextState)}},{key:"componentDidUpdate",value:function(prevProps){var light=this.props.light;this.config=(0,_utils.getConfig)(this.props,_props.defaultProps);!prevProps.light&&light&&this.setState({showPreview:!0});prevProps.light&&!light&&this.setState({showPreview:!1})}},{key:"getActivePlayer",value:function(url){for(var _i=0,_arr=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i<
_arr.length;_i++){var _Player=_arr[_i];if(_Player.canPlay(url))return _Player}return _FilePlayer.FilePlayer}},{key:"renderActivePlayer",value:function(url,activePlayer){return url?_react["default"].createElement(_Player4["default"],_extends({},this.props,{key:activePlayer.displayName,ref:this.activePlayerRef,config:this.config,activePlayer:activePlayer,onReady:this.handleReady})):null}},{key:"sortPlayers",value:function(a,b){return a&&b?a.key<b.key?-1:1:0}},{key:"render",value:function(){var _this$props=
this.props,url=_this$props.url,controls=_this$props.controls,style=_this$props.style,width=_this$props.width,height=_this$props.height,light=_this$props.light,playIcon=_this$props.playIcon;_this$props=_this$props.wrapper;var showPreview=this.state.showPreview&&url,otherProps=(0,_utils.omit)(this.props,SUPPORTED_PROPS,_props.DEPRECATED_CONFIG_PROPS),activePlayer=this.getActivePlayer(url);activePlayer=this.renderActivePlayer(url,activePlayer);controls=(0,_preload["default"])(url,controls,this.config);
controls=[activePlayer].concat(_toConsumableArray(controls)).sort(this.sortPlayers);url=_react["default"].createElement(_Preview["default"],{url:url,light:light,playIcon:playIcon,onClick:this.handleClickPreview});return _react["default"].createElement(_this$props,_extends({ref:this.wrapperRef,style:_objectSpread({},style,{width:width,height:height})},otherProps),showPreview?url:controls)}}]);return ReactPlayer}(_react.Component);exports["default"]=global;_defineProperty(global,"addCustomPlayer",function(player){customPlayers.push(player)});
_defineProperty(global,"removeCustomPlayers",function(){customPlayers=[]});_defineProperty(global,"displayName","ReactPlayer");_defineProperty(global,"propTypes",_props.propTypes);_defineProperty(global,"defaultProps",_props.defaultProps);_defineProperty(global,"canPlay",function(url){for(var _i2=0,_arr2=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i2<_arr2.length;_i2++)if(_arr2[_i2].canPlay(url))return!0;return!1});_defineProperty(global,"canEnablePIP",function(url){for(var _i3=
0,_arr3=[].concat(_toConsumableArray(customPlayers),_toConsumableArray(_players["default"]));_i3<_arr3.length;_i3++){var _Player3=_arr3[_i3];if(_Player3.canEnablePIP&&_Player3.canEnablePIP(url))return!0}return!1})}
//# sourceMappingURL=module$node_modules$react_player$lib$ReactPlayer.js.map
